body {
  font-family: Verdana, Arial, Helvetica, sans-serif;
  font-size: 90%;  
  color: #333333;
  margin: 2px;
  padding: 2px;
}

#header {
    font-size: 90%;
    background-color: #eef;
    border: 1px solid #aaa;
    font-family: Verdana, Arial, Helvetica, sans-serif;
    padding: 5px;
    margin-bottom:20px;
}
#header input {
    margin:0px;
    padding: 0;
    background-color: White;
    border: 1px solid #aaaaaa;
    font-size: 90%;
}

#footer {
    font-size: 10px;
    color: #ddd;
    margin-top:40px;
    width: 100%;
    text-align: center;
}
table.wikitable { background-color: #fff; border: 1px solid #aaa; }
table.wikitable td { background-color: #fff; border: 1px solid #aaa; }

pre {
    font-family: monospace;
    background-color: #eee;
    padding: 2px;
    padding-left: 10px;
    margin-left: 20px;
    margin-right: 20px;
}

hr {
 height: 1px;
 color: #aaaaaa;
 background-color: #aaaaaa;
 border: 0;
 margin: 0.2em 5px 0.2em 5px;
}

form {
    border: none;
    margin: 0;
}

textarea {
    border: 1px solid #aaaaaa;
    color: Black;
    background-color: white;
    width: 100%;
    padding: 0.1em;
    overflow: auto;
}

input {
    margin-top:1px;
    padding: 0 0.4em !important;
    background-color: White;
    border: 1px solid #aaaaaa;
}

a, ulink{
   color: #333;
   text-decoration:none;
   border-bottom: 1px #333 dotted;
   display: inline;
 }

a:hover {
   color: #333;
   text-decoration: None;
   border-bottom: 1px #000 solid;
   }

a:visited {
   color: #333;
}
